@@ -42,11 +42,6 @@ _ORDERED_ODL_RESOURCES = (
     odl_const.ODL_ROUTER,
     odl_const.ODL_PORT,
     odl_const.ODL_FLOATINGIP,
-    odl_const.ODL_LOADBALANCER,
-    odl_const.ODL_LISTENER,
-    odl_const.ODL_POOL,
-    odl_const.ODL_MEMBER,
-    odl_const.ODL_HEALTHMONITOR,
     odl_const.ODL_QOS_POLICY,
     odl_const.ODL_TRUNK,
     odl_const.ODL_BGPVPN,
