@@ -15,17 +15,34 @@
 
 # pylint: disable=unused-argument, protected-access
 
-import os
-import tempfile
 
-import mock
+from contextlib import contextmanager
+import io
+import os
+import sys
+import tempfile
+from unittest import mock
+
 from oslo_serialization import jsonutils
-import six
 
 from networking_odl.cmd import set_ovs_hostconfigs
 from networking_odl.tests import base
 from networking_odl.tests import match
 
+LOGGING_ENABLED = "Logging Enabled!"
+LOGGING_PERMISSION_REQUIRED = "permissions are required to configure ovsdb"
+
+
+@contextmanager
+def capture(command, args):
+    out, sys.stdout = sys.stdout, io.StringIO()
+    try:
+        command(args)
+        sys.stdout.seek(0)
+        yield sys.stdout.read()
+    finally:
+        sys.stdout = out
+
 
 class TestSetOvsHostconfigs(base.DietTestCase):
 
@@ -62,11 +79,8 @@ class TestSetOvsHostconfigs(base.DietTestCase):
         _, actual_json = execute.call_args_list[2][0][0][4].split("=", 1)
         self.assertEqual(match.json(expected), actual_json)
 
-    @mock.patch.object(
-        set_ovs_hostconfigs, 'DEFAULT_COMMAND_LINE_OPTIONS',
-        ('--host=my_host',))
     def test_given_no_args(self):
-        self._test_given_args()
+        self._test_given_args(tuple())
 
     def test_given_default_values(self):
         self._test_given_args([])
@@ -86,6 +100,9 @@ class TestSetOvsHostconfigs(base.DietTestCase):
     def test_given_noovs_dpdk(self):
         self._test_given_args(['--noovs_dpdk'])
 
+    def test_given_ovs_sriov_offload(self):
+        self._test_given_args(['--noovs_dpdk', '--ovs_sriov_offload'])
+
     def test_given_vhostuser_ovs_plug(self):
         self._test_given_args(['--vhostuser_ovs_plug'])
 
@@ -118,7 +135,7 @@ class TestSetOvsHostconfigs(base.DietTestCase):
         file_descriptor, file_path = tempfile.mkstemp()
 
         try:
-            os.write(file_descriptor, six.b("# dummy neutron config file\n"))
+            os.write(file_descriptor, b"# dummy neutron config file\n")
             os.close(file_descriptor)
             self._test_given_args(['--config-file={}'.format(file_path)])
 
@@ -195,6 +212,14 @@ class TestSetOvsHostconfigs(base.DietTestCase):
                 }
             ]
         }
+
+        if vif_type == 'ovs' and conf.ovs_sriov_offload:
+            direct_vnic = {
+                "vif_details": vif_details,
+                "vif_type": vif_type,
+                "vnic_type": "direct",
+            }
+            expected["supported_vnic_types"].append(direct_vnic)
         self.assertEqual(match.json(expected), actual_json)
 
     def test_given_ovs_dpdk_undetected(self):
@@ -262,3 +287,15 @@ class TestSetOvsHostconfigs(base.DietTestCase):
     def patch_os_geteuid(self, return_value=0):
         return self.patch(
             set_ovs_hostconfigs.os, "geteuid", return_value=return_value)
+
+    @contextmanager
+    def test_log_on_console_msg(self):
+        with capture(set_ovs_hostconfigs.main, args=()) as output:
+            self.assertNotEqual(-1, output.find(LOGGING_PERMISSION_REQUIRED))
+
+    def test_log_in_file(self):
+        with tempfile.TemporaryFile() as fp:
+            set_ovs_hostconfigs.main(("--log-file=%s" % fp.name,))
+            logs = [LOGGING_ENABLED, LOGGING_PERMISSION_REQUIRED]
+            for line, count in fp.readline():
+                self.assertNotEqual(-1, line.find(logs[count]))
