@@ -15,10 +15,11 @@
 #
 
 from datetime import timedelta
+import functools
+from unittest import mock
 
-import mock
 
-from neutron.db import api as db_api
+from neutron_lib.db import api as db_api
 
 from networking_odl.common import constants as odl_const
 from networking_odl.db import db
@@ -26,6 +27,14 @@ from networking_odl.db import models
 from networking_odl.tests.unit import test_base_db
 
 
+def in_session(fn):
+    @functools.wraps(fn)
+    def wrapper(self, *args, **kwargs):
+        with db_api.CONTEXT_WRITER.using(self.db_context):
+            return fn(self, *args, **kwargs)
+    return wrapper
+
+
 class DbTestCase(test_base_db.ODLBaseDbTestCase):
     def setUp(self):
         super(DbTestCase, self).setUp()
@@ -35,47 +44,46 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
         self._mock_function = mock.MagicMock()
 
     def _update_row(self, row):
-        self.db_session.merge(row)
-        self.db_session.flush()
+        self.db_context.session.merge(row)
+        self.db_context.session.flush()
 
     def _test_validate_updates(self, first_entry, second_entry, expected_deps,
                                state=None):
-        db.create_pending_row(self.db_session, *first_entry)
+        db.create_pending_row(self.db_context, *first_entry)
         if state:
-            row = db.get_all_db_rows(self.db_session)[0]
+            row = db.get_all_db_rows(self.db_context)[0]
             row.state = state
             self._update_row(row)
 
         deps = db.get_pending_or_processing_ops(
-            self.db_session, second_entry[1], second_entry[2])
+            self.db_context, second_entry[1], second_entry[2])
         self.assertEqual(expected_deps, len(deps) != 0)
 
     def _test_retry_count(self, retry_num, max_retry,
                           expected_retry_count, expected_state):
         # add new pending row
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
 
         # update the row with the requested retry_num
-        row = db.get_all_db_rows(self.db_session)[0]
+        row = db.get_all_db_rows(self.db_context)[0]
         row.retry_count = retry_num - 1
-        db.update_pending_db_row_retry(self.db_session, row, max_retry)
+        db.update_pending_db_row_retry(self.db_context, row, max_retry)
 
         # validate the state and the retry_count of the row
-        row = db.get_all_db_rows(self.db_session)[0]
+        row = db.get_all_db_rows(self.db_context)[0]
         self.assertEqual(expected_state, row.state)
         self.assertEqual(expected_retry_count, row.retry_count)
 
-    def _test_retry_wrapper(self, decorated_function, receives_context):
+    def _test_retry_wrapper(self, decorated_function):
         # NOTE(mpeterson): we want to make sure that it's configured
         # to MAX_RETRIES.
         self.assertEqual(db_api._retry_db_errors.max_retries,
                          db_api.MAX_RETRIES)
 
         self._test_retry_exceptions(decorated_function,
-                                    self._mock_function, receives_context,
-                                    False)
+                                    self._mock_function, False)
 
-    # NOTE(mpeterson): The following two functions serve to workaround a
+    # NOTE(mpeterson): The following function serves to workaround a
     # limitation in the discovery mechanism of pecan lib that does not allow
     # us to create a generic function that decorates on the fly. It needs to
     # be decorated through the decorator directive and not via function
@@ -84,43 +92,37 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
     def _decorated_retry_if_session_inactive(self, context):
         self._mock_function()
 
-    @db_api.retry_db_errors
-    def _decorated_retry_db_errors(self, context):
-        self._mock_function()
-
-    def test_retry_db_errors(self):
-        self._test_retry_wrapper(self._decorated_retry_db_errors,
-                                 False)
-
     def test_retry_if_session_inactive(self):
-        self._test_retry_wrapper(self._decorated_retry_if_session_inactive,
-                                 True)
+        self._test_retry_wrapper(self._decorated_retry_if_session_inactive)
 
+    @in_session
     def _test_update_row_state(self, from_state, to_state, dry_flush=False):
         # add new pending row
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
 
-        mock_flush = mock.MagicMock(side_effect=self.db_session.flush)
+        mock_flush = mock.MagicMock(
+            side_effect=self.db_context.session.flush)
 
         if dry_flush:
-            patch_flush = mock.patch.object(self.db_session, 'flush',
+            patch_flush = mock.patch.object(self.db_context.session,
+                                            'flush',
                                             side_effect=mock_flush)
 
-        row = db.get_all_db_rows(self.db_session)[0]
+        row = db.get_all_db_rows(self.db_context)[0]
         for state in [from_state, to_state]:
             if dry_flush:
                 patch_flush.start()
 
             try:
                 # update the row state
-                db.update_db_row_state(self.db_session, row, state,
+                db.update_db_row_state(self.db_context, row, state,
                                        flush=not dry_flush)
             finally:
                 if dry_flush:
                     patch_flush.stop()
 
             # validate the new state
-            row = db.get_all_db_rows(self.db_session)[0]
+            row = db.get_all_db_rows(self.db_context)[0]
             self.assertEqual(state, row.state)
 
         return mock_flush
@@ -143,17 +145,19 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
         self._test_validate_updates(self.UPDATE_ROW, self.UPDATE_ROW, True,
                                     state=odl_const.PROCESSING)
 
+    @in_session
     def test_get_oldest_pending_row_none_when_no_rows(self):
-        row = db.get_oldest_pending_db_row_with_lock(self.db_session)
+        row = db.get_oldest_pending_db_row_with_lock(self.db_context)
         self.assertIsNone(row)
 
+    @in_session
     def _test_get_oldest_pending_row_none(self, state):
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
-        row = db.get_all_db_rows(self.db_session)[0]
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
+        row = db.get_all_db_rows(self.db_context)[0]
         row.state = state
         self._update_row(row)
 
-        row = db.get_oldest_pending_db_row_with_lock(self.db_session)
+        row = db.get_oldest_pending_db_row_with_lock(self.db_context)
         self.assertIsNone(row)
 
     def test_get_oldest_pending_row_none_when_row_processing(self):
@@ -166,28 +170,29 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
         self._test_get_oldest_pending_row_none(odl_const.COMPLETED)
 
     def test_get_oldest_pending_row(self):
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
-        row = db.get_oldest_pending_db_row_with_lock(self.db_session)
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
+        row = db.get_oldest_pending_db_row_with_lock(self.db_context)
         self.assertIsNotNone(row)
         self.assertEqual(odl_const.PROCESSING, row.state)
 
+    @in_session
     def test_get_oldest_pending_row_order(self):
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
-        older_row = db.get_all_db_rows(self.db_session)[0]
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
+        older_row = db.get_all_db_rows(self.db_context)[0]
         older_row.last_retried -= timedelta(minutes=1)
         self._update_row(older_row)
 
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
-        row = db.get_oldest_pending_db_row_with_lock(self.db_session)
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
+        row = db.get_oldest_pending_db_row_with_lock(self.db_context)
         self.assertEqual(older_row, row)
 
     def _test_get_oldest_pending_row_with_dep(self, dep_state):
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
-        parent_row = db.get_all_db_rows(self.db_session)[0]
-        db.update_db_row_state(self.db_session, parent_row, dep_state)
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW,
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
+        parent_row = db.get_all_db_rows(self.db_context)[0]
+        db.update_db_row_state(self.db_context, parent_row, dep_state)
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW,
                               depending_on=[parent_row])
-        row = db.get_oldest_pending_db_row_with_lock(self.db_session)
+        row = db.get_oldest_pending_db_row_with_lock(self.db_context)
         if row is not None:
             self.assertNotEqual(parent_row.seqnum, row.seqnum)
 
@@ -201,12 +206,13 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
         row = self._test_get_oldest_pending_row_with_dep(odl_const.FAILED)
         self.assertEqual(odl_const.PROCESSING, row.state)
 
+    @in_session
     def test_get_oldest_pending_row_returns_parent_when_dep_pending(self):
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
-        parent_row = db.get_all_db_rows(self.db_session)[0]
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW,
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
+        parent_row = db.get_all_db_rows(self.db_context)[0]
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW,
                               depending_on=[parent_row])
-        row = db.get_oldest_pending_db_row_with_lock(self.db_session)
+        row = db.get_oldest_pending_db_row_with_lock(self.db_context)
         self.assertEqual(parent_row, row)
 
     def test_get_oldest_pending_row_none_when_dep_processing(self):
@@ -216,13 +222,14 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
     def test_get_oldest_pending_row_retries_exceptions(self):
         with mock.patch.object(db, 'aliased') as m:
             self._test_retry_exceptions(db.get_oldest_pending_db_row_with_lock,
-                                        m, False)
+                                        m)
 
+    @in_session
     def _test_delete_row(self, by_row=False, by_row_id=False, dry_flush=False):
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
 
-        rows = db.get_all_db_rows(self.db_session)
+        rows = db.get_all_db_rows(self.db_context)
         self.assertEqual(len(rows), 2)
         row = rows[-1]
 
@@ -234,18 +241,20 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
 
         mock_flush = None
         if dry_flush:
-            patch_flush = mock.patch.object(self.db_session, 'flush',
-                                            side_effect=self.db_session.flush)
+            patch_flush = mock.patch.object(
+                self.db_context.session, 'flush',
+                side_effect=self.db_context.session.flush
+            )
             mock_flush = patch_flush.start()
 
         try:
-            db.delete_row(self.db_session, **params)
+            db.delete_row(self.db_context, **params)
         finally:
             if dry_flush:
                 patch_flush.stop()
-                self.db_session.flush()
+                self.db_context.session.flush()
 
-        rows = db.get_all_db_rows(self.db_session)
+        rows = db.get_all_db_rows(self.db_context)
         self.assertEqual(len(rows), 1)
         self.assertNotEqual(row.seqnum, rows[0].seqnum)
 
@@ -262,29 +271,29 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
         mock_flush.assert_not_called()
 
     def test_create_pending_row(self):
-        row = db.create_pending_row(self.db_session, *self.UPDATE_ROW)
+        row = db.create_pending_row(self.db_context, *self.UPDATE_ROW)
         self.assertIsNotNone(row)
-        rows = db.get_all_db_rows(self.db_session)
+        rows = db.get_all_db_rows(self.db_context)
         self.assertTrue(row in rows)
 
     def _test_delete_rows_by_state_and_time(self, last_retried, row_retention,
                                             state, expected_rows,
                                             dry_delete=False):
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
 
         # update state and last retried
-        row = db.get_all_db_rows(self.db_session)[-1]
+        row = db.get_all_db_rows(self.db_context)[-1]
         row.state = state
         row.last_retried = row.last_retried - timedelta(seconds=last_retried)
         self._update_row(row)
 
         if not dry_delete:
-            db.delete_rows_by_state_and_time(self.db_session,
+            db.delete_rows_by_state_and_time(self.db_context,
                                              odl_const.COMPLETED,
                                              timedelta(seconds=row_retention))
 
         # validate the number of rows in the journal
-        rows = db.get_all_db_rows(self.db_session)
+        rows = db.get_all_db_rows(self.db_context)
         self.assertEqual(expected_rows, len(rows))
 
     def test_delete_completed_rows_no_new_rows(self):
@@ -296,14 +305,20 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
     def test_delete_completed_rows_wrong_state(self):
         self._test_delete_rows_by_state_and_time(10, 8, odl_const.PENDING, 1)
 
+    @in_session
     def test_delete_completed_rows_individually(self):
-        self._test_delete_rows_by_state_and_time(6, 5, odl_const.COMPLETED, 1,
-                                                 True)
-        patch_delete = mock.patch.object(self.db_session, 'delete',
-                                         side_effect=self.db_session.delete)
+        self._test_delete_rows_by_state_and_time(
+            6, 5, odl_const.COMPLETED, 1, True
+        )
+        patch_delete = mock.patch.object(
+            self.db_context.session, 'delete',
+            side_effect=self.db_context.session.delete
+        )
         mock_delete = patch_delete.start()
         self.addCleanup(patch_delete.stop)
-        self._test_delete_rows_by_state_and_time(6, 5, odl_const.COMPLETED, 0)
+        self._test_delete_rows_by_state_and_time(
+            6, 5, odl_const.COMPLETED, 0
+        )
         self.assertEqual(mock_delete.call_count, 2)
 
     @mock.patch.object(db, 'delete_row', side_effect=db.delete_row)
@@ -311,39 +326,40 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
         self._test_delete_rows_by_state_and_time(6, 5, odl_const.COMPLETED, 0)
         self.assertEqual({'flush': False}, mock_delete_row.call_args[1])
 
-    def _test_reset_processing_rows(self, session, last_retried, max_timedelta,
+    @in_session
+    def _test_reset_processing_rows(self, last_retried, max_timedelta,
                                     quantity, dry_reset=False):
-        db.create_pending_row(self.db_session, *self.UPDATE_ROW)
+        db.create_pending_row(self.db_context, *self.UPDATE_ROW)
         expected_state = odl_const.PROCESSING
 
-        row = db.get_all_db_rows(self.db_session)[-1]
+        row = db.get_all_db_rows(self.db_context)[-1]
         row.state = expected_state
         row.last_retried = row.last_retried - timedelta(seconds=last_retried)
         self._update_row(row)
 
         if not dry_reset:
             expected_state = odl_const.PENDING
-            reset = db.reset_processing_rows(self.db_session, max_timedelta)
+            reset = db.reset_processing_rows(self.db_context, max_timedelta)
             self.assertIsInstance(reset, int)
             self.assertEqual(reset, quantity)
 
-        rows = db.get_all_db_rows_by_state(self.db_session, expected_state)
+        rows = db.get_all_db_rows_by_state(self.db_context, expected_state)
 
         self.assertEqual(len(rows), quantity)
         for row in rows:
             self.assertEqual(row.state, expected_state)
 
     def test_reset_processing_rows(self):
-        self._test_reset_processing_rows(self.db_session, 6, 5, 1)
+        self._test_reset_processing_rows(6, 5, 1)
 
     def test_reset_processing_rows_no_new_rows(self):
-        self._test_reset_processing_rows(self.db_session, 0, 10, 0)
+        self._test_reset_processing_rows(0, 10, 0)
 
     @mock.patch.object(db, 'update_db_row_state',
                        side_effect=db.update_db_row_state)
     def test_reset_processing_rows_individually(self, mock_update_row):
-        self._test_reset_processing_rows(self.db_session, 6, 5, 1, True)
-        self._test_reset_processing_rows(self.db_session, 6, 5, 2)
+        self._test_reset_processing_rows(6, 5, 1, True)
+        self._test_reset_processing_rows(6, 5, 2)
         self.assertEqual(mock_update_row.call_count, 2)
         self.assertEqual(mock_update_row.call_args[1], {'flush': False})
 
@@ -378,13 +394,13 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
                                         task='test_task'):
         row = models.OpenDaylightPeriodicTask(state=existing_state,
                                               task=task)
-        self.db_session.add(row)
-        self.db_session.flush()
+        self.db_context.session.add(row)
+        self.db_context.session.flush()
 
-        self.assertEqual(expected_result, db_func(self.db_session,
+        self.assertEqual(expected_result, db_func(self.db_context,
                                                   task))
-        row = self.db_session.query(models.OpenDaylightPeriodicTask).filter_by(
-            task=task).one()
+        row = self.db_context.session.query(
+            models.OpenDaylightPeriodicTask).filter_by(task=task).one()
 
         self.assertEqual(expected_state, row['state'])
 
@@ -423,11 +439,12 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
         for count, task in enumerate(tasks):
             row.append(models.OpenDaylightPeriodicTask(state=odl_const.PENDING,
                                                        task=task))
-            self.db_session.add(row[count])
+            self.db_context.session.add(row[count])
 
-        self.db_session.flush()
+        self.db_context.session.flush()
 
-        rows = self.db_session.query(models.OpenDaylightPeriodicTask).all()
+        rows = self.db_context.session.query(
+            models.OpenDaylightPeriodicTask).all()
         self.assertEqual(len(tasks), len(rows))
 
     def _perform_ops_on_all_rows(self, tasks, to_lock):
@@ -442,12 +459,12 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
 
         processed = []
         for task in tasks:
-            row = self.db_session.query(
+            row = self.db_context.session.query(
                 models.OpenDaylightPeriodicTask).filter_by(task=task).one()
 
             self.assertEqual(row['state'], curr_state)
-            self.assertTrue(func(self.db_session, task))
-            rows = self.db_session.query(
+            self.assertTrue(func(self.db_context, task))
+            rows = self.db_context.session.query(
                 models.OpenDaylightPeriodicTask).filter_by().all()
 
             processed.append(task)
@@ -458,7 +475,7 @@ class DbTestCase(test_base_db.ODLBaseDbTestCase):
                 else:
                     self.assertEqual(curr_state, row['state'])
 
-        self.assertFalse(func(self.db_session, tasks[-1]))
+        self.assertFalse(func(self.db_context, tasks[-1]))
 
     def test_multiple_row_tasks_lock_unlock(self):
         task1 = 'test_random_task'
