@@ -15,10 +15,9 @@
 
 import os
 import signal
-import time
+from unittest import mock
 
 import fixtures
-import mock
 
 from neutron.common import utils
 from oslo_db import exception
@@ -51,7 +50,7 @@ class JournalPeriodicProcessorTest(base_v2.OpenDaylightConfigBase,
         super(JournalPeriodicProcessorTest, self).setUp()
         self.periodic_task_fixture = self.useFixture(
             base.OpenDaylightPeriodicTaskFixture())
-        self.cfg.config(sync_timeout=0, group='ml2_odl')
+        self.cfg.config(sync_timeout=0.1, group='ml2_odl')
 
     def _create_periodic_processor(self):
         periodic_processor = worker.JournalPeriodicProcessor()
@@ -72,7 +71,7 @@ class JournalPeriodicProcessorTest(base_v2.OpenDaylightConfigBase,
             # Skip ps header
             f.readline()
 
-            processes = (l.strip().split()[:3] for l in f)
+            processes = (line.strip().split()[:3] for line in f)
 
             return next(((c, s) for p, s, c in processes if int(p) == pid),
                         (None, None))
@@ -81,6 +80,11 @@ class JournalPeriodicProcessorTest(base_v2.OpenDaylightConfigBase,
         if self._get_pid_status(pid)[1] in PROCESS_RUNNING_STATUSES:
             os.kill(pid, signal.SIGKILL)
 
+    def mock_object_with_ipc(self, target, attribute, pre_hook=None):
+        patcher = mock.patch.object(target, attribute, autospec=True)
+        c2p_read = self.create_ipc_for_mock(patcher, pre_hook)
+        return c2p_read
+
     def create_ipc_for_mock(self, patcher, pre_hook=None):
         # NOTE(mpeterson): The following pipe is being used because this is
         # testing something inter processeses and we need to have a value on
@@ -104,16 +108,21 @@ class JournalPeriodicProcessorTest(base_v2.OpenDaylightConfigBase,
         self.addCleanup(patcher.stop)
 
         def was_called(*args, **kwargs):
-            os.close(c2p_read)
+            # OSError is caught because start is called twice on the worker
+            # and the second time the pipe is already closed.
             try:
-                if pre_hook:
-                    pre_hook(*args, **kwargs)
-                os.write(c2p_write, b'1')
-            except Exception:
-                # This is done so any read on the pipe is unblocked.
-                os.write(c2p_write, b'0')
-            finally:
-                os.close(c2p_write)
+                os.close(c2p_read)
+                try:
+                    if pre_hook:
+                        pre_hook(*args, **kwargs)
+                    os.write(c2p_write, b'1')
+                except Exception:
+                    # This is done so any read on the pipe is unblocked.
+                    os.write(c2p_write, b'0')
+                finally:
+                    os.close(c2p_write)
+            except OSError:
+                pass
 
         mock_.side_effect = was_called
 
@@ -175,17 +184,19 @@ class JournalPeriodicProcessorTest(base_v2.OpenDaylightConfigBase,
     def _create_periodic_processor_ipc_fork(self, target, pre_hook=None):
         self._setup_mocks_for_periodic_task()
 
-        mock_patcher = mock.patch.object(worker.JournalPeriodicProcessor,
-                                         target, autospec=True)
+        real_start = worker.JournalPeriodicProcessor.start
+        pipe_start = self.mock_object_with_ipc(worker.JournalPeriodicProcessor,
+                                               'start', real_start)
 
-        c2p_read = self.create_ipc_for_mock(mock_patcher, pre_hook)
+        c2p_read = self.mock_object_with_ipc(worker.JournalPeriodicProcessor,
+                                             target, pre_hook)
 
         pid = self._spawn_service(
             service_maker=lambda: worker.JournalPeriodicProcessor())
         self.addCleanup(self._kill_process, pid)
 
         # Allow the process to spawn and signal handling to be registered
-        time.sleep(0.3)
+        self.assert_ipc_mock_called(pipe_start)
 
         return pid, c2p_read
 
@@ -371,13 +382,13 @@ class OpenDaylightJournalThreadTest(base_v2.OpenDaylightTestCase):
 
     def test_entry_reset_retries_exceptions(self):
         with mock.patch.object(db, 'update_db_row_state') as m:
-            self._test_retry_exceptions(
-                journal.entry_reset, m, True)
+            self._test_retry_exceptions(journal.entry_reset, m)
 
+    @test_db.in_session
     @mock.patch.object(client.OpenDaylightRestClient, 'sendjson',
                        mock.Mock(side_effect=Exception))
     def test__sync_entry_update_state_by_retry_count_on_exception(self):
-        entry = db.create_pending_row(self.db_session, *self.UPDATE_ROW)
+        entry = db.create_pending_row(self.db_context, *self.UPDATE_ROW)
         self.journal._max_retry_count = 1
         self.assertEqual(entry.retry_count, 0)
         self.journal._sync_entry(self.db_context, entry)
@@ -388,7 +399,7 @@ class OpenDaylightJournalThreadTest(base_v2.OpenDaylightTestCase):
         self.assertEqual(entry.state, odl_const.FAILED)
 
     def _test__sync_entry_logs(self, log_type):
-        entry = db.create_pending_row(self.db_session, *self.UPDATE_ROW)
+        entry = db.create_pending_row(self.db_context, *self.UPDATE_ROW)
         logger = self.useFixture(fixtures.FakeLogger())
 
         self.journal._sync_entry(self.db_context, entry)
@@ -450,15 +461,15 @@ class JournalTest(base_v2.OpenDaylightTestCase):
 
     def test_entry_complete_retries_exceptions(self):
         with mock.patch.object(db, 'update_db_row_state') as m:
-            self._test_retry_exceptions(journal.entry_complete, m, True)
+            self._test_retry_exceptions(journal.entry_complete, m)
 
+    @test_db.in_session
     def _test_entry_complete(self, retention, expected_length):
         self.cfg.config(completed_rows_retention=retention, group='ml2_odl')
-        db.create_pending_row(self.db_session,
-                              *test_db.DbTestCase.UPDATE_ROW)
-        entry = db.get_all_db_rows(self.db_session)[-1]
+        db.create_pending_row(self.db_context, *test_db.DbTestCase.UPDATE_ROW)
+        entry = db.get_all_db_rows(self.db_context)[-1]
         journal.entry_complete(self.db_context, entry)
-        rows = db.get_all_db_rows(self.db_session)
+        rows = db.get_all_db_rows(self.db_context)
         self.assertEqual(expected_length, len(rows))
         self.assertTrue(
             all(row.state == odl_const.COMPLETED for row in rows))
@@ -472,53 +483,50 @@ class JournalTest(base_v2.OpenDaylightTestCase):
     def test_entry_complete_with_indefinite_retention(self):
         self._test_entry_complete(-1, 1)
 
+    @test_db.in_session
     def test_entry_complete_with_retention_deletes_dependencies(self):
         self.cfg.config(completed_rows_retention=1, group='ml2_odl')
-        db.create_pending_row(self.db_session,
-                              *test_db.DbTestCase.UPDATE_ROW)
-        entry = db.get_all_db_rows(self.db_session)[-1]
-        db.create_pending_row(self.db_session,
-                              *test_db.DbTestCase.UPDATE_ROW,
+        db.create_pending_row(self.db_context, *test_db.DbTestCase.UPDATE_ROW)
+        entry = db.get_all_db_rows(self.db_context)[-1]
+        db.create_pending_row(self.db_context, *test_db.DbTestCase.UPDATE_ROW,
                               depending_on=[entry])
-        dependant = db.get_all_db_rows(self.db_session)[-1]
+        dependant = db.get_all_db_rows(self.db_context)[-1]
         journal.entry_complete(self.db_context, entry)
-        rows = db.get_all_db_rows(self.db_session)
+        rows = db.get_all_db_rows(self.db_context)
         self.assertIn(entry, rows)
         self.assertEqual([], entry.dependencies)
         self.assertEqual([], dependant.depending_on)
 
     def test_entry_reset_retries_exceptions(self):
         with mock.patch.object(db, 'update_db_row_state') as m:
-            self._test_retry_exceptions(journal.entry_reset, m, True)
+            self._test_retry_exceptions(journal.entry_reset, m)
 
+    @test_db.in_session
     def test_entry_reset(self):
-        db.create_pending_row(self.db_session,
-                              *test_db.DbTestCase.UPDATE_ROW)
-        db.create_pending_row(self.db_session,
-                              *test_db.DbTestCase.UPDATE_ROW)
-        entry = db.get_all_db_rows(self.db_session)[-1]
+        db.create_pending_row(self.db_context, *test_db.DbTestCase.UPDATE_ROW)
+        db.create_pending_row(self.db_context, *test_db.DbTestCase.UPDATE_ROW)
+        entry = db.get_all_db_rows(self.db_context)[-1]
         entry.state = odl_const.PROCESSING
-        self.db_session.merge(entry)
-        self.db_session.flush()
-        entry = db.get_all_db_rows(self.db_session)[-1]
+        self.db_context.session.merge(entry)
+        self.db_context.session.flush()
+        entry = db.get_all_db_rows(self.db_context)[-1]
         self.assertEqual(entry.state, odl_const.PROCESSING)
         journal.entry_reset(self.db_context, entry)
-        rows = db.get_all_db_rows(self.db_session)
+        rows = db.get_all_db_rows(self.db_context)
         self.assertEqual(2, len(rows))
         self.assertTrue(all(row.state == odl_const.PENDING for row in rows))
 
     def test_entry_set_retry_count_retries_exceptions(self):
         with mock.patch.object(db, 'update_pending_db_row_retry') as m:
             self._test_retry_exceptions(
-                journal.entry_update_state_by_retry_count, m, True)
+                journal.entry_update_state_by_retry_count, m)
 
+    @test_db.in_session
     def test_entry_set_retry_count(self):
-        db.create_pending_row(self.db_session,
-                              *test_db.DbTestCase.UPDATE_ROW)
-        entry_baseline = db.get_all_db_rows(self.db_session)[-1]
-        db.create_pending_row(self.db_session,
-                              *test_db.DbTestCase.UPDATE_ROW)
-        entry_target = db.get_all_db_rows(self.db_session)[-1]
+        db.create_pending_row(self.db_context, *test_db.DbTestCase.UPDATE_ROW)
+        entry_baseline = db.get_all_db_rows(self.db_context)[-1]
+        db.create_pending_row(self.db_context, *test_db.DbTestCase.UPDATE_ROW)
+        entry_target = db.get_all_db_rows(self.db_context)[-1]
         self.assertEqual(entry_target.retry_count, 0)
         self.assertEqual(entry_target.retry_count, entry_baseline.retry_count)
         self.assertEqual(entry_target.state, entry_baseline.state)
@@ -543,7 +551,7 @@ class JournalTest(base_v2.OpenDaylightTestCase):
             self.assertIn(arg, logger.output)
 
     def test_record_logs_dependencies(self):
-        entry = db.create_pending_row(self.db_session, *self.UPDATE_ROW)
+        entry = db.create_pending_row(self.db_context, *self.UPDATE_ROW)
 
         logger = self.useFixture(fixtures.FakeLogger(level=logging.DEBUG))
         journal.record(self.db_context, *self.UPDATE_ROW)
