@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from neutron.plugins.ml2 import driver_context as ctx
 from neutron_lib.api.definitions import portbindings
