@@ -12,7 +12,9 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from mock import patch
+from unittest.mock import patch
+
+from neutron_lib.db import api as db_api
 
 from networking_odl.common import constants as odl_const
 from networking_odl.db import db
@@ -35,7 +37,7 @@ class TestOpenDaylightSFCDriverV2(base_v2.OpenDaylightConfigBase):
         ).start().return_value
 
         mocked_fc_context.current = sfc_const.FAKE_PORT_PAIR
-        mocked_fc_context.session = self.db_session
+        mocked_fc_context.session = self.db_context.session
         mocked_fc_context._plugin_context = mocked_fc_context
         return mocked_fc_context
 
@@ -45,7 +47,7 @@ class TestOpenDaylightSFCDriverV2(base_v2.OpenDaylightConfigBase):
         ).start().return_value
 
         mocked_fc_context.current = sfc_const.FAKE_PORT_PAIR_GROUP
-        mocked_fc_context.session = self.db_session
+        mocked_fc_context.session = self.db_context.session
         mocked_fc_context._plugin_context = mocked_fc_context
         return mocked_fc_context
 
@@ -55,7 +57,7 @@ class TestOpenDaylightSFCDriverV2(base_v2.OpenDaylightConfigBase):
         ).start().return_value
 
         mocked_fc_context.current = sfc_const.FAKE_PORT_CHAIN
-        mocked_fc_context.session = self.db_session
+        mocked_fc_context.session = self.db_context.session
         mocked_fc_context._plugin_context = mocked_fc_context
         return mocked_fc_context
 
@@ -70,17 +72,19 @@ class TestOpenDaylightSFCDriverV2(base_v2.OpenDaylightConfigBase):
 
     def _test_event(self, operation, timing, resource_str,
                     object_type):
-        context = self._get_mock_operation_context(object_type)
-        self._call_operation_object(operation, timing, resource_str, context)
-        if timing == 'precommit':
-            self.db_session.flush()
-        row = db.get_oldest_pending_db_row_with_lock(self.db_session)
+        with db_api.CONTEXT_WRITER.using(self.db_context):
+            context = self._get_mock_operation_context(object_type)
+            self._call_operation_object(operation, timing,
+                                        resource_str, context)
+            if timing == 'precommit':
+                self.db_context.session.flush()
+            row = db.get_oldest_pending_db_row_with_lock(self.db_context)
 
-        if timing == 'precommit':
-            self.assertEqual(operation, row['operation'])
-            self.assertEqual(object_type, row['object_type'])
-        elif timing == 'after':
-            self.assertIsNone(row)
+            if timing == 'precommit':
+                self.assertEqual(operation, row['operation'])
+                self.assertEqual(object_type, row['object_type'])
+            elif timing == 'after':
+                self.assertIsNone(row)
 
     # TODO(yamahata): utilize test scenarios
     def test_create_port_pair_precommit(self):
