@@ -15,7 +15,6 @@
 
 from unittest import mock
 
-from neutron.services.trunk import callbacks
 from neutron.services.trunk import models
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import resources
@@ -63,15 +62,14 @@ class TestTrunkHandler(base_v2.OpenDaylightConfigBase):
                         OpenDaylightTrunkHandlerV2())
 
     def _fake_trunk_payload(self):
-        payload = callbacks.TrunkPayload(
-            self.db_context, 'fake_id',
-            mock.Mock(return_value=FAKE_TRUNK),
-            mock.Mock(return_value=FAKE_TRUNK),
-            mock.Mock(return_value=FAKE_TRUNK['sub_ports']))
-        payload.current_trunk.status = trunk_consts.TRUNK_DOWN_STATUS
-        payload.current_trunk.to_dict = mock.Mock(return_value=FAKE_TRUNK)
-        payload.original_trunk.status = trunk_consts.TRUNK_DOWN_STATUS
-        payload.original_trunk.to_dict = mock.Mock(return_value=FAKE_TRUNK)
+        payload = events.DBEventPayload(
+            self.db_context, resource_id='fake_id',
+            states=(mock.Mock(return_value=FAKE_TRUNK),
+                    mock.Mock(return_value=FAKE_TRUNK),))
+        payload.latest_state.status = trunk_consts.TRUNK_DOWN_STATUS
+        payload.latest_state.to_dict = mock.Mock(return_value=FAKE_TRUNK)
+        payload.states[0].status = trunk_consts.TRUNK_DOWN_STATUS
+        payload.states[0].to_dict = mock.Mock(return_value=FAKE_TRUNK)
         return payload
 
     def _call_operation_object(self, operation, timing, fake_payload):
@@ -90,7 +88,7 @@ class TestTrunkHandler(base_v2.OpenDaylightConfigBase):
             if timing == 'precommit':
                 self.assertEqual(operation, row['operation'])
                 self.assertEqual(odl_const.ODL_TRUNK, row['object_type'])
-                self.assertEqual(fake_payload.trunk_id, row['object_uuid'])
+                self.assertEqual(fake_payload.resource_id, row['object_uuid'])
             elif timing == 'after':
                 self.assertIsNone(row)
 
@@ -188,12 +186,13 @@ class TestTrunkHandler(base_v2.OpenDaylightConfigBase):
         port = FAKE_PARENT.copy()
         original_port = FAKE_PARENT.copy()
         original_port['status'] = n_const.PORT_STATUS_DOWN
-        port_kwargs = {'port': port, 'original_port': original_port}
+        payload = events.DBEventPayload(None, None, None,
+                                        states=(original_port, port))
 
         mock_get_subports_ids.return_value = ['fake_port_id']
 
         self.handler.trunk_subports_update_status(resource, event_type,
-                                                  mock.ANY, **port_kwargs)
+                                                  mock.ANY, payload)
 
         mock_set_subport_status.assert_called_once_with(
             core_plugin, mock.ANY, 'fake_port_id', n_const.PORT_STATUS_ACTIVE)
@@ -210,12 +209,13 @@ class TestTrunkHandler(base_v2.OpenDaylightConfigBase):
         port = FAKE_PARENT.copy()
         original_port = FAKE_PARENT.copy()
         port['status'] = n_const.PORT_STATUS_DOWN
-        port_kwargs = {'port': port, 'original_port': original_port}
+        payload = events.DBEventPayload(None, None, None,
+                                        states=(original_port, port))
 
         mock_get_subports_ids.return_value = ['fake_port_id']
 
         self.handler.trunk_subports_update_status(resource, event_type,
-                                                  mock.ANY, **port_kwargs)
+                                                  mock.ANY, payload)
 
         mock_set_subport_status.assert_called_once_with(
             core_plugin, mock.ANY, 'fake_port_id', n_const.PORT_STATUS_DOWN)
